@@ -13,7 +13,7 @@ class JointExcessFromEjk:
     @staticmethod
     def get_excess_joint_distributions(
         ejks: JointExcessJointDegreeMatrices,
-    ) -> dict[dict]:
+    ) -> dict:
 
         if len(ejks._ejks) != len(ejks.excess_degree_keys):
             raise ("Error in JointExcessDDFromEjk: incorrect ejk or keys provided")
